# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2015 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

from oslo_log import log as logging
from cinder.i18n import _, _LE, _LI, _LW
from cinder.volume.drivers.ibm.storwize_svc import helpers

LOG = logging.getLogger(__name__)


class PowerVCStorwizeHelpers(helpers.StorwizeHelpers):

    def __init__(self, run_ssh):
        super(PowerVCStorwizeHelpers, self).__init__(run_ssh)

    def add_fc_wwpns(self, storage_nodes):
        """Over riding community code to add only
           active ports to the node wwpn list
        """
        for key in storage_nodes:
            node = storage_nodes[key]
            resp = self.ssh.lsnode(node_id=node['id'])
            wwpns = set(node['WWPN'])
            for i, s in resp.select('port_id', 'port_status'):
                if 'active' == s or 'inactive' == s:
                    wwpns.add(i)
            node['WWPN'] = list(wwpns)
            LOG.info(_LI('WWPN on node %(node)s: %(wwpn)s')
                     % {'node': node['id'], 'wwpn': node['WWPN']})
