#
# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2014, 2015 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

import os
import eventlet
import threading
import ConfigParser
from signal import SIGTERM
eventlet.monkey_patch(os=False)

from oslo_config import cfg
from nova import config
config.parse_args([])

import nova.context
from nova.conductor import rpcapi

COND = threading.Condition()
HAS_FINISHED = False


def notify_unmanage(mgmt_ip):
    """Notifies the old Management System it is removing its Management"""
    global HAS_FINISHED
    ctxt = nova.context.get_admin_context()
    #If the Host isn't currently being managed, nothing to do
    if not _is_currently_managed(ctxt):
        return
    #Use the Conductor on the Old Management System to Remove the Host
    conductor_api = rpcapi.ConductorAPI()
    cctxt = conductor_api.client.prepare()
    #We will kick off a timer thread to make sure we don't wait forever
    eventlet.greenthread.spawn(_rpc_timeout_timer)
    #Make the RPC Call to remove the Host from the original Management System
    cctxt.call(ctxt, 'notify_unmanage', host=cfg.CONF.host, mgmt_ip=mgmt_ip)
    #Notify the Timeout Timer that we have finished the RPC call
    COND.acquire()
    HAS_FINISHED = True
    COND.notifyAll()
    COND.release()


def _is_currently_managed(context):
    """Helper method to see verify the Host is currently managed"""
    parser = ConfigParser.RawConfigParser()
    parser.read('/etc/nova/nova.conf')
    #Check the management_ip to determine if the Host is currently managed
    if parser.has_option('DEFAULT', 'management_ip'):
        return len(parser.get('DEFAULT', 'management_ip')) > 0
    return False


def _rpc_timeout_timer():
    """Helper method to timeout the RPC call if it takes too long"""
    global HAS_FINISHED
    COND.acquire()
    #If the RPC call didn't complete already, wait for it
    if HAS_FINISHED is False:
        COND.wait(60)
    COND.release()
    #If we timed out and the RPC call never returned, kill the process
    if HAS_FINISHED is False:
        os.kill(os.getpid(), SIGTERM)
